@@ -1,11 +1,8 @@
 # ***********************************************************************************
-# Author:tony qin
+# Author:Tony
 # Create time:2020.12.08
 # The software is build 4 SSAP poc testing.
-# Vision of (SSAP)Self Service analytics platform is to promote every users to grasp the self-service analytics capability.
-
-# %$ → [Next plan: GUI, pop up web visualization, eng charts.]
-# duty cycle, normality test report,
+# ctrl+shift+'-'
 
 #>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
 
@@ -30,11 +27,11 @@ def docs():
     print(
         "[1] ssap.info()\n"
         "[2] ssap.docs()\n"
-        "[3] ssap.bsfcmap(speed,torque,bsfc,title,level)\n"
-        "[4] ssap.dutycycle(speed,torque,x1,x2,stepx,xlabel,y1,y2,stepy,ylabel,bubblesize,title)\n"
-        "[5] ssap.dutycycle3d(speed,torque,3dbar_num,title)\n"
-        "[6] ssap.boxplot01(parameter column,label,title)\n"
-        "[7] ssap.boxplot02(dataframe,title)\n"
+        "[3] ssap.bsfcmap(df, speed_name, torque_name, bsfc_name, title, level)\n"
+        "[4] ssap.dutycycle(df, speed_name, torque_name, stepx, stepy, bubblesize, title)\n"
+        "[5] ssap.dutycycle3d(df,speed_name, torque_name, barnum, title)\n"
+        "[6] ssap.boxplot01(df, parameter_name, title)\n"
+        "[7] ssap.boxplot02(df, title)\n"
         "[8] ssap.boxplot03(df, category_x_name, value_y_name, title)\n"
         "[9] ssap.pdsclean(df)\n"
         "[10] ssap.cmd()\n"
@@ -72,12 +69,13 @@ def docs():
 # ※※other common python commands:
 def cmd():
     print(
-        "[1] pd.concat([df1,df2]) - 'combine df'\n"
-        "[2] list(df) - 'show all column name'\n"
+        "[1] pd.concat([df1,df2]) | 'combine df'\n"
+        "[2] list(df) | 'show all column name'\n"
         "[3] 'remove duplicate rows'\n"
         "[4] 'delete columns'\n"
         "[5] 'filter dataset with conditions'\n"
         "[6] 'remove nan'\n"
+        "[7] 'change column name'\n"
     )
 
 
@@ -106,8 +104,8 @@ def bsfcmap(df, speed_name, torque_name, bsfc_name, title, level):
     plt.contourf(X, Y, Z, level, alpha=.75, cmap='plasma')
     plt.colorbar()
     plt.clabel(C, inline=True, fontsize=10, colors='black')
-    plt.xlabel('Engine_Speed(rpm)')
-    plt.ylabel('Engine_Torque(N.m)')
+    plt.xlabel(speed_name)
+    plt.ylabel(torque_name)
     plt.title(title)
     plt.show()
 
@@ -212,7 +210,7 @@ def boxplot01(df, parameter_name, title):
 
     par = df[parameter_name]
 
-    red_square = dict(markerfacecolor='red', marker='o', alpha=0.5, lw=1)
+    red_square = dict(markerfacecolor='lightgrey', marker='o', alpha=0.5, lw=1)
 
     B = ax1.boxplot(par, labels=labels, flierprops=red_square)
     # B = B.set(color='blue')
@@ -365,10 +363,19 @@ def pdsclean(df):
     return df
 
 
-# boxscatterplot
+# pandas profiling
+def dfprofile(df):
+    from pandas_profiling import ProfileReport
+    import webbrowser
 
+    df = df
+    profile = ProfileReport(df, title='SSAP - Dataset Profile Report', html={'style': {'full_width': True}})
 
+    profile.to_file("profile_file.html")
+    url = 'profile_file.html'
+    webbrowser.open(url, new=2)
 
+    return profile
 
 
 
@@ -384,5 +391,4 @@ def pdsclean(df):
 # Scatter + hist
 # data analytics ppt里的图表
 # python培训材料里的图表
-
 # 多因子相关性矩阵图/
\ No newline at end of file
